==> mame_0.175.orig.tar.xz: mame-0.175/3rdparty/README.md <==
# **3rdparty** #

benchmark - [Apache License, Version 2.0](http://opensource.org/licenses/Apache-2.0) (used only for testing, not part of distribution)

bgfx - [The BSD 2-Clause License](http://opensource.org/licenses/BSD-2-Clause)

bx - [The BSD 2-Clause License](http://opensource.org/licenses/BSD-2-Clause)

compat - Wine headers missing in MinGW [The GNU Lesser General Public License, version 2.1 (LGPL-2.1)](http://opensource.org/licenses/LGPL-2.1)

**note that this one contain headers only and that real library/dll is dynamically loaded so use in commercial project is allowed, will be removed when becomes part of MinGW distribution**

dxsdk - [DirectX SDK EULA](https://github.com/mamedev/mame/blob/master/3rdparty/dxsdk/Documentation/License%20Agreements/DirectX%20SDK%20EULA.txt)

expat - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

genie - [The BSD 3-Clause License](http://opensource.org/licenses/BSD-3-Clause)

glm - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

googletest - [The BSD 3-Clause License](http://opensource.org/licenses/BSD-3-Clause)

libflac - [The BSD 3-Clause License](http://opensource.org/licenses/BSD-3-Clause)

libjpeg - [Custom BSD-like](https://github.com/numenta/nupic/blob/master/external/licenses/LICENSE.libjpeg-6b.txt)

libuv - [Node License (BSD-like)](https://github.com/mamedev/mame/blob/master/3rdparty/libuv/LICENSE)

lua - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

lua-zlib - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

luabridge - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

luafilesystem - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

lzma - [The GNU Lesser General Public License](http://opensource.org/licenses/LGPL-2.1)

nanosvg - [zlib license](http://opensource.org/licenses/Zlib)

portaudio - [The MIT License (MIT)](http://opensource.org/licenses/MIT) explanation at [their site](http://www.portaudio.com/license.html)

portmidi - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

pugixml - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

rapidjson - [The BSD 3-Clause License](http://opensource.org/licenses/BSD-3-Clause)

sdl2 - [zlib license](http://opensource.org/licenses/Zlib)

softfloat - [U.C. Berkeley open-source license](https://github.com/mamedev/mame/blob/master/3rdparty/softfloat/README.txt) MIT compatible

winpcap - [The BSD 3-Clause License](http://opensource.org/licenses/BSD-3-Clause)

zlib - [zlib license](http://opensource.org/licenses/Zlib)

==> mame_0.218+dfsg.1.orig.tar.xz: mame-0.218+dfsg.1/3rdparty/README.md <==
# **3rdparty** #

asio - [Boost Software License](http://www.boost.org/LICENSE_1_0.txt)

benchmark - [Apache License, Version 2.0](http://opensource.org/licenses/Apache-2.0) (used only for testing, not part of distribution)

bgfx - [The BSD 2-Clause License](http://opensource.org/licenses/BSD-2-Clause)

bimg - [The BSD 2-Clause License](http://opensource.org/licenses/BSD-2-Clause)

bx - [The BSD 2-Clause License](http://opensource.org/licenses/BSD-2-Clause)

catch - [Boost Software License](http://www.boost.org/LICENSE_1_0.txt)

compat - Wine headers missing in MinGW [The GNU Lesser General Public License, version 2.1 (LGPL-2.1)](http://opensource.org/licenses/LGPL-2.1)

**note that this one contain headers only and that real library/dll is dynamically loaded so use in commercial project is allowed, will be removed when becomes part of MinGW distribution**

dxsdk - [DirectX SDK EULA](https://github.com/mamedev/mame/blob/master/3rdparty/dxsdk/Documentation/License%20Agreements/DirectX%20SDK%20EULA.txt)

expat - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

genie - [The BSD 3-Clause License](http://opensource.org/licenses/BSD-3-Clause)

glm - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

libflac - [The BSD 3-Clause License](http://opensource.org/licenses/BSD-3-Clause)

libjpeg - [Custom BSD-like](https://github.com/numenta/nupic/blob/master/external/licenses/LICENSE.libjpeg-6b.txt)

linenoise-ng - [The BSD 3-Clause License](http://opensource.org/licenses/BSD-3-Clause)

lsqlite3 - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

lua - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

lua-linenoise - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

lua-zlib - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

luafilesystem - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

lzma - [The GNU Lesser General Public License](http://opensource.org/licenses/LGPL-2.1)

minimp3 - [Creative Commons Zero v1.0 Universal](https://creativecommons.org/publicdomain/zero/1.0/)

nanosvg - [zlib license](http://opensource.org/licenses/Zlib)

portaudio - [The MIT License (MIT)](http://opensource.org/licenses/MIT) explanation at [their site](http://www.portaudio.com/license.html)

portmidi - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

pugixml - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

rapidjson - [The BSD 3-Clause License](http://opensource.org/licenses/BSD-3-Clause)

sdl2 - [zlib license](http://opensource.org/licenses/Zlib)

softfloat - ["Softfloat 2b" U.C. Berkeley modified license](https://github.com/mamedev/mame/blob/master/3rdparty/softfloat/README.txt) MIT compatible

softfloat3 - [The BSD 3-Clause License](http://opensource.org/licenses/BSD-3-Clause)

sol2 - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

sqlite3 - Public Domain

tap-windows6.h - Dual-licensed [The GNU General Public License, version 2](https://opensource.org/licenses/GPL-2.0) and [The MIT License (MIT)](http://opensource.org/licenses/MIT)

utf8proc - [The MIT License (MIT)](http://opensource.org/licenses/MIT)

winpcap - [The BSD 3-Clause License](http://opensource.org/licenses/BSD-3-Clause)

zlib - [zlib license](http://opensource.org/licenses/Zlib)
